// CSliderBar.h
//
// Part of Tinter, a small app to demonstrate QColorMatrix.
// Use at your own risk. Comments welcome.
//
// (c) 2003, Sjaak Priester, Amsterdam.
// mailto:sjaak@sjaakpriester.nl

#pragma once

// Special Windows message to notify the View of any
// change in the slider positions.
// WPARAM is one of IDC_CONTRAST... IDC_GAMMA, or zero for Set Neutral.
// LPARAM is not used.
#define QM_SLIDERBAR	WM_APP

class CSliderBar : public CDialogBar
{
public:
	CSliderBar();
	virtual ~CSliderBar();

	enum { IDD = IDD_SLIDERBAR };

	// Get the values of the sliders in 'external' format.
	REAL GetContrast() const			{ return GetValue(IDC_CONTRAST); }
	REAL GetBrightness() const			{ return GetValue(IDC_BRIGHTNESS); }
	REAL GetSaturation() const			{ return GetValue(IDC_SATURATION); }
	REAL GetHue() const					{ return GetValue(IDC_HUE); }
	REAL GetGamma() const				{ return GetValue(IDC_GAMMA); }

	// Set the values.
	void SetContrast(REAL contrast)		{ SetValue(IDC_CONTRAST, contrast); }
	void SetBrightness(REAL brightness)	{ SetValue(IDC_BRIGHTNESS, brightness); }
	void SetSaturation(REAL saturation)	{ SetValue(IDC_SATURATION, saturation); }
	void SetHue(REAL hue)				{ SetValue(IDC_HUE, hue); }
	void SetGamma(REAL gamma)			{ SetValue(IDC_GAMMA, gamma); }

	// Set the sliders in the neutral position.
	void SetNeutral(void);

	// true if at least one of the sliders is not in the neutral position.
	bool IsDirty(void);

protected:
	afx_msg LRESULT OnInitDialog(WPARAM wParam, LPARAM lParam);
	afx_msg void OnHScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar);
	afx_msg void OnBnClickedNeutral();
	afx_msg void OnUpdateCommandNeutral(CCmdUI * pCmdUI);

	REAL GetValue(UINT id) const;
	void SetValue(UINT id, REAL value);
	void UpdateBuddy(CSliderCtrl * pSlider);
	LRESULT NotifyView(UINT id);

	DECLARE_DYNAMIC(CSliderBar)
	DECLARE_MESSAGE_MAP()
};
